import { Modal } from '@/components/a/modal';
import { useShallow } from 'zustand/shallow';
import { useHomeStore } from '../store';
import { useEffect, useState } from 'react';
import { queryLogin } from '@/modules/query';
import { Button } from '@/components/a/button';
export const Label = ({ label, children }: { label: string; children: React.ReactNode }) => {
  return (
    <div className='text-sm text-gray-500 w-full flex gap-2'>
      <div className='min-w-[60px]'>{label}</div>
      <div className=''>{children}</div>
    </div>
  );
};
export const SuccessModal = () => {
  const { openSuccessModal, setOpenSuccessModal, appKey, version, filename } = useHomeStore(
    useShallow((state) => ({
      openSuccessModal: state.openSuccessModal,
      setOpenSuccessModal: state.setOpenSuccessModal,
      appKey: state.appKey, //
      version: state.version, //
      filename: state.filename, //
    })),
  );
  const [link, setLink] = useState<string>('');
  useEffect(() => {
    getLink();
  }, [openSuccessModal, appKey, filename]);
  const getLink = async () => {
    const user = await queryLogin.checkLocalUser();
    if (!user) {
      setLink('');
      return;
    }
    const _currentHref = new URL(window.location.href);
    const username = user?.username;
    const _filename = filename;
    let pathname = `/${username}/${appKey}/`;
    if (_filename.endsWith('.html')) {
      if (_filename !== 'index.html') {
        pathname += _filename;
      }
    }
    const newHref = new URL(pathname, _currentHref.origin);
    const link = newHref.toString();
    setLink(link);
    return link;
  };
  return (
    <Modal open={openSuccessModal} setOpen={setOpenSuccessModal} title='部署成功'>
      <div>
        <div className='flex flex-col gap-2 w-[400px] min-h-[100px] text-black'>
          <Label label='应用 Key: '>{appKey}</Label>
          <Label label='版本:'>{version}</Label>
          <Label label='访问地址:'>
            <a href={link} className='text-blue-500' rel='noreferrer'>
              {link}
            </a>
          </Label>
          <Label label='配置地址:'>
            <a href={`/root/center/app/edit/list`} className='text-blue-500' target='_self' rel='noreferrer'>
              {`/root/center/app/edit/list`}
            </a>
          </Label>
          <div className='mt-1 text-gray-500 italic' style={{ fontSize: 10 }}>
            注: 如果需要其他人访问，需要设置共享。
          </div>

          <div className='mt-4 flex justify-end'>
            <Button onClick={() => setOpenSuccessModal(false)}>知道了</Button>
          </div>
        </div>
      </div>
    </Modal>
  );
};
