import { useForm, Controller } from 'react-hook-form';
import { TextField } from '../components';
import { Button } from '@/components/a/button';
import { AutoComplate } from '@/components/a/auto-complate';
import { TagsInput } from '@/components/a/input';
import { useManagerStore } from '../store';
import { useShallow } from 'zustand/shallow';
import { useEffect } from 'react';
import { useTranslation } from 'react-i18next';
import { pick } from 'lodash-es';
import { toast } from 'react-toastify';
import { Select } from '@/components/a/select';
import { MarkTypes } from '../constant';

export const EditMark = () => {
  const { control, handleSubmit, reset } = useForm();
  const { updateMark, markData, setCurrentMarkId, setMarkData } = useManagerStore(
    useShallow((state) => {
      return {
        updateMark: state.updateMark,
        markData: state.markData,
        setCurrentMarkId: state.setCurrentMarkId,
        currentMarkId: state.currentMarkId,
        setMarkData: state.setMarkData,
      };
    }),
  );
  // const [mark, setMark] = useState<Mark | undefined>(markData);
  const mark = pick(markData, ['id', 'title', 'description', 'markType', 'summary', 'tags', 'link', 'thumbnail']);
  useEffect(() => {
    reset(mark);
    console.log('markData', markData);
  }, [markData?.id]);
  const onSubmit = async (data: any) => {
    const res = await updateMark({ ...mark, ...data });
    if (res.code === 200) {
      toast.success('编辑成功');
    }

    // setCurrentMarkId('');
    // setMarkData(undefined);
  };
  return (
    <form onSubmit={handleSubmit(onSubmit)} noValidate autoComplete='off' className='w-full h-full overflow-auto px-2 py-1'>
      <Controller
        name='title'
        control={control}
        defaultValue={mark?.title || ''}
        render={({ field }) => (
          <div className='mb-4'>
            <label className='block text-sm font-medium mb-1'>标题</label>
            <input {...field} className='w-full px-3 py-2 border border-gray-300 rounded focus:outline-none focus:ring-2 focus:ring-blue-500' type='text' />
          </div>
        )}
      />
      <Controller
        name='description'
        control={control}
        defaultValue={mark?.description || ''}
        render={({ field }) => (
          <div className='mb-4'>
            <label className='block text-sm font-medium mb-1'>描述</label>
            <textarea {...field} className='w-full px-3 py-2 border border-gray-300 rounded focus:outline-none focus:ring-2 focus:ring-blue-500' rows={3} />
          </div>
        )}
      />
      <Controller
        name='markType'
        control={control}
        defaultValue={mark?.markType || ''}
        render={({ field }) => {
          return (
            <div className='mb-4'>
              <label className='block text-sm font-medium mb-1'>类型</label>
              <AutoComplate
                {...field}
                options={MarkTypes.map((item) => {
                  return { label: item, value: item };
                })}
                onChange={(value) => field.onChange(value)}
              />
            </div>
          );
        }}
      />
      <Controller
        name='summary'
        control={control}
        defaultValue={mark?.summary || ''}
        render={({ field }) => (
          <div className='mb-4'>
            <label className='block text-sm font-medium mb-1'>概要</label>
            <textarea {...field} className='w-full px-3 py-2 border border-gray-300 rounded focus:outline-none focus:ring-2 focus:ring-blue-500' rows={2} />
          </div>
        )}
      />
      <Controller
        name='tags'
        control={control}
        defaultValue={mark?.tags || ''}
        render={({ field }) => {
          const label = '标签';
          return (
            <div className='mb-4'>
              <label className='block text-sm font-medium mb-1'>标签</label>
              <TagsInput
                {...field}
                options={field.value?.map((tag: string) => ({ label: tag, value: tag })) || []}
                placeholder={label}
                onChange={(value) => {
                  field.onChange(value);
                  console.log('tags', value);
                }}
              />
            </div>
          );
        }}
      />
      <Controller
        name='link'
        control={control}
        defaultValue={mark?.link || ''}
        render={({ field }) => (
          <div className='mb-4'>
            <label className='block text-sm font-medium mb-1'>链接</label>
            <input {...field} className='w-full px-3 py-2 border border-gray-300 rounded focus:outline-none focus:ring-2 focus:ring-blue-500' type='text' />
          </div>
        )}
      />
      <Controller
        name='thumbnail'
        control={control}
        defaultValue={mark?.thumbnail || ''}
        render={({ field }) => (
          <div className='mb-4'>
            <label className='block text-sm font-medium mb-1'>缩略图</label>
            <input {...field} className='w-full px-3 py-2 border border-gray-300 rounded focus:outline-none focus:ring-2 focus:ring-blue-500' type='text' />
          </div>
        )}
      />
      <div className='flex gap-2'>
        <Button type='submit' color='primary'>
          保存
        </Button>
        <Button
          color='secondary'
          onClick={() => {
            setCurrentMarkId('');
            setMarkData(undefined);
          }}>
          取消
        </Button>
      </div>
    </form>
  );
};
